summaryrefslogtreecommitdiffstats
path: root/src/libs/engine/ObjectStore.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/libs/engine/ObjectStore.h')
-rw-r--r--src/libs/engine/ObjectStore.h18
1 files changed, 9 insertions, 9 deletions
diff --git a/src/libs/engine/ObjectStore.h b/src/libs/engine/ObjectStore.h
index 8c71c002..e008887c 100644
--- a/src/libs/engine/ObjectStore.h
+++ b/src/libs/engine/ObjectStore.h
@@ -28,13 +28,13 @@ namespace Om {
class Patch;
class Node;
class Port;
-class OmObject;
+class GraphObject;
-/** Storage for all OmObjects (tree of OmObject's sorted by path).
+/** Storage for all GraphObjects (tree of GraphObject's sorted by path).
*
* All looking up in pre_process() methods (and anything else that isn't in-band
* with the audio thread) should use this (to read and modify the OmObject
* tree).
*/
class ObjectStore
@@ -43,16 +43,16 @@ public:
Patch* find_patch(const Path& path);
Node* find_node(const Path& path);
Port* find_port(const Path& path);
- OmObject* find(const Path& path);
+ GraphObject* find(const Path& path);
- void add(OmObject* o);
- void add(TreeNode<OmObject*>* o);
- TreeNode<OmObject*>* remove(const string& key);
+ void add(GraphObject* o);
+ void add(TreeNode<GraphObject*>* o);
+ TreeNode<GraphObject*>* remove(const string& key);
- const Tree<OmObject*>& objects() { return m_objects; }
+ const Tree<GraphObject*>& objects() { return m_objects; }
private:
- Tree<OmObject*> m_objects;
+ Tree<GraphObject*> m_objects;
};
@@ -28,13 +28,13 @@ namespace Om {
*
* All looking up in pre_process() methods (and anything else that isn't in-band
- * with the audio thread) should use this (to read and modify the OmObject
+ * with the audio thread) should use this (to read and modify the GraphObject
* tree).
*/